import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useRef, useState } from "react";
import { MultipleTestContainersOverview, getBorderStyles, useWaitForIframeTestContainers } from "../..";
import { IframeTestStatsDisplay } from "../stats/IframeTestStatsDisplay";
const IframeStateAndOverview = ({ iframeUrl, iframeProps, onIframeTestsComplete, ...props }) => {
    const [iframeState, setIframeState] = useState("Pending");
    const iframeRef = useRef(null);
    const [readyUrl, setReadyUrl] = useState(null);
    const handleIframeContainerReady = () => {
        setReadyUrl(iframeUrl);
        setIframeState("Test Container Available");
    };
    useEffect(() => {
        // When a new iframe url is passed in, the iframe state should be reset.
        setIframeState("Pending");
    }, [iframeUrl]);
    useWaitForIframeTestContainers(iframeUrl, iframeRef, handleIframeContainerReady);
    const isCurrentUrlReady = readyUrl === iframeUrl;
    // Initialize the iframe state string.
    let iframeStateString = iframeState;
    if (iframeState === "Pending") {
        iframeStateString = "Pending url: " + iframeUrl;
    }
    else {
        // TODO (maybe): Add more states here?
    }
    // console.log("iframeUrl -", iframeUrl, ";;;;;",
    //   "currentRefUrl -", readyUrl, ";;;;;",
    //   "iframeState -", iframeState, ";;;;;",
    //   "iframeStateString -", iframeStateString, ";;;;;",
    //   "isCurrentUrlReady -", isCurrentUrlReady);
    return _jsxs("div", { ...props, children: [_jsx("iframe", { src: iframeUrl, ref: (el) => {
                    if (!el) {
                        // el is null when the component is unmounted. We're not interested in this case.
                        return;
                    }
                    iframeRef.current = el;
                }, ...iframeProps }), !isCurrentUrlReady && _jsx("div", { className: "rbt-overview " + getBorderStyles("Pending"), children: iframeStateString }), isCurrentUrlReady && _jsx(MultipleTestContainersOverview, { iframeUrl: iframeUrl, onAllTestsComplete: onIframeTestsComplete })] });
};
// Initialization function for testContainerStates.
function initTestContainerStates(urls) {
    const states = {};
    urls.forEach(url => {
        states[url] = [];
    });
    return states;
}
// Single iframe mode component
const SingleIframeOverview = ({ urls, iframeProps, ...props }) => {
    const [currentIframeUrl, setCurrentIframeUrl] = useState(urls[0]);
    // Define a state to hold the test container states for each URL.
    const [testContainerStates, setTestContainerStates] = useState(initTestContainerStates(urls));
    const handleIframeTestsComplete = (containerStateArray) => {
        const currentIframeUrl = containerStateArray[0].iframeUrl;
        if (!currentIframeUrl) {
            throw new Error("SingleIframeOverview - iframe url is not defined in the test container state");
        }
        // Update the state with the new test container state for the current URL
        setTestContainerStates(prevStates => ({
            ...prevStates,
            [currentIframeUrl]: containerStateArray,
        }));
        const nextUrlIndex = urls.indexOf(currentIframeUrl) + 1;
        if (nextUrlIndex < urls.length) {
            setCurrentIframeUrl(urls[nextUrlIndex]);
        }
    };
    return (_jsxs("div", { ...props, children: [_jsx(IframeStateAndOverview, { iframeUrl: currentIframeUrl, iframeProps: iframeProps, onIframeTestsComplete: handleIframeTestsComplete, 
                // XXX: NOTE: Hide the overview stats here. IframeTestStatsDisplay will handle the stats.
                style: {
                    display: "none"
                } }), Object.entries(testContainerStates).map(([url, containerStateArray], index) => (_jsx(IframeTestStatsDisplay, { containerStates: containerStateArray, iframeUrl: url }, `${url}-${index}`)))] }));
};
// Multiple iframes mode component
const MultipleIframeOverview = ({ urls, iframeProps, ...props }) => {
    return (_jsx("div", { ...props, children: urls.map(url => (_jsx(IframeStateAndOverview, { iframeUrl: url, iframeProps: iframeProps }, url))) }));
};
// Main component to decide which component to render
export const MultiplePageOverview = ({ singleIframeMode, ...props }) => {
    if (props.urls.length === 0) {
        throw new Error("No urls provided to MultiplePageOverview");
    }
    if (singleIframeMode) {
        return _jsx(SingleIframeOverview, { ...props });
    }
    else {
        return _jsx(MultipleIframeOverview, { ...props });
    }
};
