import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useGetContainerStateUntilAllTestsFinish } from "../../lib/hooks";
import { getBorderStyles, getTestArrayFromContainerState, getTestStats, groupTests } from "../../lib/testHelpers";
import { TestArrayStats } from "../stats/TestArrayStats";
import { TestStatsDisplay } from "../stats/TestStatsDisplay";
export const SingleTestContainerOverview = ({ containerId, iframeUrl, title, testsCompleteCallback, showGroupStats = false, ...props }) => {
    const containerState = useGetContainerStateUntilAllTestsFinish(containerId, iframeUrl, testsCompleteCallback);
    const testsArray = getTestArrayFromContainerState(containerState);
    const groupedTests = groupTests(testsArray, "(no test group)");
    const uniqueTestGroupTitles = Object.keys(groupedTests);
    const isLoading = !containerState;
    const containerStats = getTestStats(Object.values(containerState?.tests || []));
    const classNames = "rbt-overview " + getBorderStyles(containerStats.state);
    if (isLoading) {
        const loadingString = iframeUrl ? `Loading container for iframe '${iframeUrl}'` : `Loading tests for container id '${containerId}'`;
        return _jsx("div", { className: "rbt-overview " + getBorderStyles("Pending"), children: loadingString });
    }
    return (_jsxs("div", { className: classNames, ...props, children: [_jsxs("div", { className: "rbt-overview-title-and-stats", children: [!!title && _jsx("span", { className: "rbt-test-title", children: title }), _jsx(TestStatsDisplay, { testStats: containerStats })] }), showGroupStats && uniqueTestGroupTitles.map((groupTitle) => (_jsx(TestArrayStats, { groupTitle: groupTitle, tests: groupedTests[groupTitle] }, groupTitle)))] }));
};
